# Matrix operations library
Ide o zápočtový program pre predmet Programovanie 1 na Matfyze.
Program robí základné operácie s maticami:
- sčítanie/odčítanie
- násobenie skalárom, maticou
- úprava na REF/RREF tvar
- test regularity matice a hľadanie matice inverznej
- stopa, hodnosť, transpozícia matice

## Link na PyPI
Knižnicu taktiež nájdete na PyPI: https://pypi.org/project/matrix-operations-cuni/0.6.1/
